'use client'

import React, { useState, useEffect } from 'react'
import { motion, useAnimation, AnimatePresence } from 'framer-motion'
import { useInView } from 'react-intersection-observer'
import { ChevronLeft, ChevronRight } from 'lucide-react'

interface TestimonialProps {
  quote: string
  author: string
  icon: string
}

const testimonials: TestimonialProps[] = [
  {
    quote: "I recommend this service to everyone I know. Simply superb!",
    author: "Emily Johnson",
    icon: "/placeholder.svg?height=50&width=50"
  },
  {
    quote: "This product has transformed the way we operate. Excellent quality and amazing support!",
    author: "Jane Doe",
    icon: "/placeholder.svg?height=50&width=50"
  },
  {
    quote: "A fantastic solution to our business needs. We couldn't be happier with the results!",
    author: "John Smith",
    icon: "/placeholder.svg?height=50&width=50"
  },
  {
    quote: "Incredible service and outstanding results. Highly recommended!",
    author: "Michael Brown",
    icon: "/placeholder.svg?height=50&width=50"
  },
  {
    quote: "The team's expertise and dedication are unmatched. A game-changer for our company!",
    author: "Sarah Davis",
    icon: "/placeholder.svg?height=50&width=50"
  }
]

const Testimonial3Section: React.FC = () => {
  const [currentIndex, setCurrentIndex] = useState(1)
  const controls = useAnimation()
  const [ref, inView] = useInView({
    triggerOnce: true,
    threshold: 0.1,
  })

  useEffect(() => {
    if (inView) {
      controls.start('visible')
    }
  }, [controls, inView])

  const nextSlide = () => {
    setCurrentIndex((prevIndex) => (prevIndex + 1) % testimonials.length)
  }

  const prevSlide = () => {
    setCurrentIndex((prevIndex) => (prevIndex - 1 + testimonials.length) % testimonials.length)
  }

  const getTestimonials = () => {
    const prev = (currentIndex - 1 + testimonials.length) % testimonials.length
    const next = (currentIndex + 1) % testimonials.length
    return [testimonials[prev], testimonials[currentIndex], testimonials[next]]
  }

  return (
    <section ref={ref} className="t3s-section bg-gradient-to-br from-purple-200 to-blue-200 py-16 px-4">
      <div className="t3s-container max-w-6xl mx-auto">
        <motion.h2 
          className="t3s-title text-4xl md:text-5xl font-bold text-center mb-12"
          initial="hidden"
          animate={controls}
          variants={{
            hidden: { opacity: 0, y: -20 },
            visible: { opacity: 1, y: 0, transition: { duration: 0.5 } }
          }}
        >
          <span className="t3s-gradient-text">WHAT OUR CLIENTS SAY</span>
        </motion.h2>
        <div className="t3s-slider-container relative">
          <div className="t3s-testimonials-wrapper flex justify-center items-center">
            {getTestimonials().map((testimonial, index) => (
              <motion.div
                key={index}
                className={`t3s-testimonial-card bg-white bg-opacity-20 backdrop-blur-lg rounded-lg p-6 shadow-lg mx-2 ${index === 1 ? 't3s-active' : 't3s-inactive'}`}
                initial={{ opacity: 0, scale: 0.8 }}
                animate={{ opacity: 1, scale: 1 }}
                transition={{ duration: 0.5 }}
              >
                <img src={testimonial.icon} alt="Client" className="t3s-client-icon w-12 h-12 rounded-full mb-4 mx-auto" />
                <p className="t3s-quote text-lg text-gray-800 mb-4">{testimonial.quote}</p>
                <p className="t3s-author text-gray-600 font-semibold">- {testimonial.author}</p>
              </motion.div>
            ))}
          </div>
          <button 
            className="t3s-nav-btn t3s-prev absolute top-1/2 left-0 transform -translate-y-1/2 bg-gray-800 text-white p-2 rounded-full"
            onClick={prevSlide}
          >
            <ChevronLeft size={24} />
          </button>
          <button 
            className="t3s-nav-btn t3s-next absolute top-1/2 right-0 transform -translate-y-1/2 bg-gray-800 text-white p-2 rounded-full"
            onClick={nextSlide}
          >
            <ChevronRight size={24} />
          </button>
        </div>
      </div>
    </section>
  )
}

export default Testimonial3Section